@@ -27,6 +27,7 @@
 #include <kcalcore/memorycalendar.h>
 
 #include <qtest.h>
+#include <QTimeZone>
 
 QTEST_MAIN(DndFactoryTest)   // clipboard() needs GUI
 
@@ -36,14 +37,15 @@ using namespace KCalUtils;
 void DndFactoryTest::testPasteAllDayEvent()
 {
 
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(QString()));
+    MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
 
     DndFactory factory(calendar);
 
     Event::Ptr allDayEvent(new Event());
     allDayEvent->setSummary(QStringLiteral("Summary 1"));
-    allDayEvent->setDtStart(KDateTime(QDate(2010, 8, 8)));
-    allDayEvent->setDtEnd(KDateTime(QDate(2010, 8, 9)));
+    allDayEvent->setDtStart(QDateTime(QDate(2010, 8, 8), {}));
+    allDayEvent->setDtEnd(QDateTime(QDate(2010, 8, 9), {}));
+    allDayEvent->setAllDay(true);
     const QString originalUid = allDayEvent->uid();
     const bool originalIsAllDay = allDayEvent->allDay();
 
@@ -75,14 +77,15 @@ void DndFactoryTest::testPasteAllDayEvent()
 void DndFactoryTest::testPasteAllDayEvent2()
 {
 
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(QString()));
+    MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
 
     DndFactory factory(calendar);
 
     Event::Ptr allDayEvent(new Event());
     allDayEvent->setSummary(QStringLiteral("Summary 2"));
-    allDayEvent->setDtStart(KDateTime(QDate(2010, 8, 8)));
-    allDayEvent->setDtEnd(KDateTime(QDate(2010, 8, 9)));
+    allDayEvent->setDtStart(QDateTime(QDate(2010, 8, 8), {}));
+    allDayEvent->setDtEnd(QDateTime(QDate(2010, 8, 9), {}));
+    allDayEvent->setAllDay(true);
     const QString originalUid = allDayEvent->uid();
 
     Incidence::List incidencesToPaste;
@@ -90,7 +93,7 @@ void DndFactoryTest::testPasteAllDayEvent2()
 
     QVERIFY(factory.copyIncidences(incidencesToPaste));
 
-    const KDateTime newDateTime(QDate(2011, 1, 1));
+    const QDateTime newDateTime(QDate(2011, 1, 1));
     const uint originalLength = allDayEvent->dtStart().secsTo(allDayEvent->dtEnd());
 
     // paste at the new time
@@ -118,27 +121,27 @@ void DndFactoryTest::testPasteAllDayEvent2()
              << "; new dtStart is " << pastedEvent->dtStart()
              << " and new dtEnd is " << pastedEvent->dtEnd();
 #endif
-    QVERIFY(originalLength == newLength);
-    QVERIFY(pastedEvent->dtStart() == newDateTime);
-    QVERIFY(pastedEvent->summary() == allDayEvent->summary());
+    QCOMPARE(newLength, originalLength);
+    QCOMPARE(newDateTime, pastedEvent->dtStart());
+    QCOMPARE(allDayEvent->summary(), pastedEvent->summary());
 }
 
 void DndFactoryTest::testPasteTodo()
 {
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(QString()));
+    MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
 
     DndFactory factory(calendar);
 
     Todo::Ptr todo(new Todo());
     todo->setSummary(QStringLiteral("Summary 1"));
-    todo->setDtDue(KDateTime(QDate(2010, 8, 9)));
+    todo->setDtDue(QDateTime(QDate(2010, 8, 9), {}));
 
     Incidence::List incidencesToPaste;
     incidencesToPaste.append(todo);
 
     QVERIFY(factory.copyIncidences(incidencesToPaste));
 
-    const KDateTime newDateTime(QDate(2011, 1, 1), QTime(10, 10));
+    const QDateTime newDateTime(QDate(2011, 1, 1), QTime(10, 10));
 
     Incidence::List pastedIncidences = factory.pasteIncidences(newDateTime);
     QVERIFY(pastedIncidences.size() == 1);
@@ -152,7 +155,7 @@ void DndFactoryTest::testPasteTodo()
 
     Todo::Ptr pastedTodo = incidence.staticCast<Todo>();
 
-    QVERIFY(pastedTodo->dtDue() == newDateTime);
-    QVERIFY(pastedTodo->summary() == todo->summary());
+    QCOMPARE(newDateTime, pastedTodo->dtDue());
+    QCOMPARE(todo->summary(), pastedTodo->summary());
 
 }
